@@ -113,7 +113,7 @@ QVariant UpdateModel::data(const QModelIndex &index, int role) const
     case Qt::CheckStateRole:
         return item->checked();
     case SizeRole:
-        return KFormat().formatByteSize(item->size());
+        return item->size() > 0 ? KFormat().formatByteSize(item->size()) : i18n("Unknown");
     case ResourceRole:
         return QVariant::fromValue<QObject *>(item->resource());
     case ResourceProgressRole:
@@ -123,8 +123,8 @@ QVariant UpdateModel::data(const QModelIndex &index, int role) const
     case ChangelogRole:
         return item->changelog();
     case SectionRole: {
-        static const QString appUpdatesSection = i18nc("@item:inlistbox", "Application Updates");
-        static const QString systemUpdateSection = i18nc("@item:inlistbox", "System Updates");
+        static const QString appUpdatesSection = i18nc("@item:inlistbox", "Applications");
+        static const QString systemUpdateSection = i18nc("@item:inlistbox", "System Software");
         static const QString addonsSection = i18nc("@item:inlistbox", "Addons");
         switch (item->resource()->type()) {
         case AbstractResource::Application:
@@ -305,7 +305,13 @@ UpdateItem *UpdateModel::itemFromResource(AbstractResource *res)
 
 QString UpdateModel::updateSize() const
 {
-    return m_updates ? KFormat().formatByteSize(m_updates->updateSize()) : QString();
+    if (!m_updates) {
+        return QString();
+    }
+    if (m_updates->updateSize() != 0) {
+        return KFormat().formatByteSize(m_updates->updateSize());
+    }
+    return i18n("Unknown");
 }
 
 QModelIndex UpdateModel::indexFromItem(UpdateItem *item) const
@@ -346,3 +352,5 @@ void UpdateModel::uncheckAll()
         if (index(i, 0).data(Qt::CheckStateRole) != Qt::Unchecked)
             setData(index(i, 0), Qt::Unchecked, Qt::CheckStateRole);
 }
+
+#include "moc_UpdateModel.cpp"
