@@ -184,12 +184,14 @@ bool AbstractResource::categoryMatches(Category *cat)
             return false;
     }
 
-    Q_FOREACH (const auto &filter, cat->andFilters()) {
+    const auto andFilters = cat->andFilters();
+    for (const auto &filter : andFilters) {
         if (!shouldFilter(this, filter))
             return false;
     }
 
-    Q_FOREACH (const auto &filter, cat->notFilters()) {
+    const auto notFilters = cat->notFilters();
+    for (const auto &filter : notFilters) {
         if (shouldFilter(this, filter))
             return false;
     }
@@ -199,7 +201,7 @@ bool AbstractResource::categoryMatches(Category *cat)
 static QSet<Category *> walkCategories(AbstractResource *res, const QVector<Category *> &cats)
 {
     QSet<Category *> ret;
-    foreach (Category *cat, cats) {
+    for (Category *cat : cats) {
         if (res->categoryMatches(cat)) {
             const auto subcats = walkCategories(res, cat->subCategories());
             if (subcats.isEmpty()) {
@@ -222,7 +224,7 @@ QString AbstractResource::categoryDisplay() const
 {
     const auto matchedCategories = categoryObjects(CategoryModel::global()->rootCategories());
     QStringList ret;
-    foreach (auto cat, matchedCategories) {
+    for (auto cat : matchedCategories) {
         ret.append(cat->name());
     }
     ret.sort();
@@ -237,7 +239,7 @@ QUrl AbstractResource::url() const
 
 QString AbstractResource::displayOrigin() const
 {
-    return i18nc("origin (backend name)", "%1 (%2)", origin(), backend()->displayName());
+    return origin();
 }
 
 QString AbstractResource::executeLabel() const
@@ -268,3 +270,21 @@ QString AbstractResource::upgradeText() const
         return available;
     }
 }
+
+QString AbstractResource::versionString()
+{
+    const QString version = isInstalled() ? installedVersion() : availableVersion();
+    if (version.isEmpty()) {
+        return {};
+    } else {
+        QLocale l;
+        const QString releaseString = l.toString(releaseDate(), QLocale::ShortFormat);
+        if (!releaseString.isEmpty()) {
+            return i18n("%1, released on %2", version, releaseString);
+        } else {
+            return version;
+        }
+    }
+}
+
+#include "moc_AbstractResource.cpp"
