@@ -9,10 +9,12 @@
 
 #include "libdiscover_debug.h"
 #include <QMetaProperty>
+#include <cmath>
 #include <utils.h>
 
 #include "ResourcesModel.h"
 #include <Category/CategoryModel.h>
+#include <KLocalizedString>
 #include <ReviewsBackend/Rating.h>
 #include <Transaction/TransactionModel.h>
 
@@ -55,6 +57,14 @@ ResourcesProxyModel::ResourcesProxyModel(QObject *parent)
     connect(this, &QAbstractItemModel::modelReset, this, &ResourcesProxyModel::countChanged);
     connect(this, &QAbstractItemModel::rowsInserted, this, &ResourcesProxyModel::countChanged);
     connect(this, &QAbstractItemModel::rowsRemoved, this, &ResourcesProxyModel::countChanged);
+
+    QTimer *roughCountTimer = new QTimer(this);
+    roughCountTimer->setInterval(10);
+    roughCountTimer->setSingleShot(true);
+
+    connect(roughCountTimer, &QTimer::timeout, this, &ResourcesProxyModel::roughCountChanged);
+    connect(this, &ResourcesProxyModel::countChanged, roughCountTimer, qOverload<>(&QTimer::start));
+    connect(this, &ResourcesProxyModel::busyChanged, roughCountTimer, qOverload<>(&QTimer::start));
 }
 
 void ResourcesProxyModel::componentComplete()
@@ -350,7 +360,13 @@ bool ResourcesProxyModel::lessThan(AbstractResource *leftPackage, AbstractResour
     } else if (role == CanUpgrade) {
         ret = leftValue.toBool();
     } else {
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
         ret = leftValue < rightValue;
+#else
+        const auto order = QVariant::compare(leftValue, rightValue);
+        Q_ASSERT(order != QPartialOrdering::Unordered);
+        return order == QPartialOrdering::Less;
+#endif
     }
     return ret != (order != Qt::AscendingOrder);
 }
@@ -638,3 +654,21 @@ bool ResourcesProxyModel::sortByRelevancy() const
 {
     return m_sortByRelevancy;
 }
+
+QString ResourcesProxyModel::roughCount() const
+{
+    const int rows = rowCount();
+    if (isBusy()) {
+        // We return an empty string because it's evidently confusing
+        if (rows == 0) {
+            return {};
+        }
+
+        // We convert rows=1234 into round=1000
+        const int round = std::pow(10, std::floor(std::log10(rows)));
+        if (round >= 1) {
+            return i18nc("an approximation number, like 3000+", "%1+", (rows / round) * round);
+        }
+    }
+    return QString::number(rows);
+}
