@@ -16,23 +16,32 @@
 class OneTimeAction : public QObject
 {
 public:
-    OneTimeAction(const std::function<void()> &func, QObject *parent)
+    // the int argument is only so the compile knows to tell the constructors apart
+    OneTimeAction(int /*unnecessary*/, const std::function<bool()> &func, QObject *parent)
         : QObject(parent)
         , m_function(func)
     {
     }
 
+    OneTimeAction(const std::function<void()> &func, QObject *parent)
+        : QObject(parent)
+        , m_function([func] {
+            func();
+            return true;
+        })
+    {
+    }
+
     void trigger()
     {
         if (m_done)
             return;
-        m_done = true;
-        m_function();
+        m_done = m_function();
         deleteLater();
     }
 
 private:
-    std::function<void()> m_function;
+    std::function<bool()> m_function;
     bool m_done = false;
 };
 
@@ -113,13 +122,13 @@ static QVector<T> kSetToVector(const QSet<T> &set)
         ret.append(x);
     return ret;
 }
-
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
 template<typename T>
 static QSet<T> kToSet(const QVector<T> &set)
 {
     return QSet<T>(set.begin(), set.end());
 }
-
+#endif
 template<typename T>
 static QSet<T> kToSet(const QList<T> &set)
 {
