@@ -16,8 +16,11 @@
 #include <KNotification>
 
 class KNotification;
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
 class QNetworkConfigurationManager;
+#endif
 class UnattendedUpdates;
+class UpdatesSettings;
 
 class DiscoverNotifier : public QObject
 {
@@ -65,6 +68,10 @@ public:
     {
         return m_isBusy;
     }
+    UpdatesSettings *settings() const
+    {
+        return m_settings;
+    }
 
 public Q_SLOTS:
     void recheckSystemUpdateNeeded();
@@ -91,11 +98,13 @@ private:
     bool m_hasUpdates = false;
     bool m_needsReboot = false;
     bool m_isBusy = false;
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     QNetworkConfigurationManager *m_manager = nullptr;
+#endif
     QPointer<KNotification> m_updatesAvailableNotification;
     UnattendedUpdates *m_unattended = nullptr;
     KConfigWatcher::Ptr m_settingsWatcher;
-    class UpdatesSettings *m_settings;
+    UpdatesSettings *m_settings;
 };
 
 #endif // ABSTRACTKDEDMODULE_H
